@@ -1,12 +1,10 @@
 from argparse import Namespace
 
-from . import data
-from .plugin import _get_plugins
+from .data import *
 
 
 def handle_list(
     args: Namespace,
-    plugin_list: dict,
     group_id: str,
     is_admin: bool,
     is_superuser: bool,
@@ -15,14 +13,7 @@ def handle_list(
 
     if args.store:
         if is_superuser:
-            message += "商店插件列表如下："
-            store_plugin_list = _get_plugins()
-            for i in range(len(store_plugin_list)):
-                if store_plugin_list[i]["id"] in plugin_list:
-                    message += f'\n[o] {store_plugin_list[i]["id"]}'
-                else:
-                    message += f'\n[x] {store_plugin_list[i]["id"]}'
-            return message
+            return get_store_pulgin_list()
         else:
             return "获取商店插件列表需要超级用户权限！"
 
@@ -40,18 +31,16 @@ def handle_list(
         else:
             return "获取指定群插件列表需要超级用户权限！"
 
-    message += "插件列表如下："
-    for plugin in plugin_list:
-        if group_id in plugin_list[plugin]:
-            message += f'\n[{"o" if plugin_list[plugin][group_id] else "x"}] {plugin}'
-        else:
-            message += f'\n[{"o" if plugin_list[plugin]["0"] else "x"}] {plugin}'
+    message += "插件列表如下：\n"
+    message += "\n".join(
+        f"[{'o' if get_group_plugin_list(group_id)[plugin] else 'x'}] {plugin}"
+        for plugin in get_group_plugin_list(group_id)
+    )
     return message
 
 
 def handle_block(
     args: Namespace,
-    plugin_list: dict,
     group_id: str,
     is_admin: bool,
     is_superuser: bool,
@@ -76,24 +65,12 @@ def handle_block(
         else:
             return "管理指定群插件需要超级用户权限！"
 
-    message += "结果如下："
-    for plugin in args.plugins if not args.all else plugin_list:
-        message += "\n"
-        if plugin in plugin_list:
-            if not group_id in plugin_list[plugin] or plugin_list[plugin][group_id]:
-                plugin_list[plugin][group_id] = False
-                message += f"插件{plugin}屏蔽成功！"
-            else:
-                message += f"插件{plugin}已经屏蔽！"
-        else:
-            message += f"插件{plugin}不存在！"
-    data.dump(plugin_list)
+    message += block_plugin(group_id, *args.plugins)
     return message
 
 
 def handle_unblock(
     args: Namespace,
-    plugin_list: dict,
     group_id: str,
     is_admin: bool,
     is_superuser: bool,
@@ -117,24 +94,25 @@ def handle_unblock(
         else:
             return "管理指定群插件需要超级用户权限！"
 
-    message += "结果如下："
-    for plugin in args.plugins if not args.all else plugin_list:
-        message += "\n"
-        if plugin in plugin_list:
-            if not group_id in plugin_list[plugin] or not plugin_list[plugin][group_id]:
-                plugin_list[plugin][group_id] = True
-                message += f"插件{plugin}启用成功！"
-            else:
-                message += f"插件{plugin}已经启用！"
-        else:
-            message += f"插件{plugin}不存在！"
-    data.dump(plugin_list)
+    message += unblock_plugin(group_id, *args.plugins)
     return message
 
 
+def handle_info(
+    args: Namespace,
+    group_id: str,
+    is_admin: bool,
+    is_superuser: bool,
+) -> str:
+
+    if not is_admin and not is_superuser:
+        return "管理插件需要超级权限！"
+
+    return get_store_plugin_info(args.plugin)
+
+
 def handle_install(
     args: Namespace,
-    plugin_list: dict,
     group_id: str,
     is_admin: bool,
     is_superuser: bool,
@@ -144,7 +122,6 @@ def handle_install(
 
 def handle_update(
     args: Namespace,
-    plugin_list: dict,
     group_id: str,
     is_admin: bool,
     is_superuser: bool,
@@ -154,7 +131,6 @@ def handle_update(
 
 def handle_uninstall(
     args: Namespace,
-    plugin_list: dict,
     group_id: str,
     is_admin: bool,
     is_superuser: bool,
